[Libreoffice-commits] core.git: 2 commits - filter/source sd/source

Zhe Wang wangzcdl at apache.org
Sun Feb 23 13:01:45 PST 2014


 filter/source/msfilter/svdfppt.cxx   |   17 ++++++++++-------
 sd/source/ui/dlg/headerfooterdlg.cxx |    6 +++---
 2 files changed, 13 insertions(+), 10 deletions(-)

New commits:
commit 3b45f92ba6659836572d366aeda2b5bcedcae7f0
Author: Zhe Wang <wangzcdl at apache.org>
Date:   Mon Jun 25 05:24:31 2012 +0000

    Resolves: #i119985# date/time is displayed as different language
    
    (cherry picked from commit 977a050343fc836fc3e7bd876afaee931c47252c)
    
    Change-Id: I1f31f6731353b2d8b8fd684fc6ea29becfd4a814

diff --git a/filter/source/msfilter/svdfppt.cxx b/filter/source/msfilter/svdfppt.cxx
index fa1d06f..392e30e 100644
--- a/filter/source/msfilter/svdfppt.cxx
+++ b/filter/source/msfilter/svdfppt.cxx
@@ -4780,13 +4780,16 @@ sal_Bool PPTTextSpecInfoAtomInterpreter::Read( SvStream& rIn, const DffRecordHea
             }
             if ( nLang )
             {
-                sal_uInt16 nScriptType = GetI18NScriptTypeOfLanguage( nLang );
-                if ( nScriptType & SCRIPTTYPE_LATIN )
-                    pEntry->nLanguage[ 0 ] = nLang;
-                if ( nScriptType & SCRIPTTYPE_ASIAN )
-                    pEntry->nLanguage[ 1 ] = nLang;
-                if ( nScriptType & SCRIPTTYPE_COMPLEX )
-                    pEntry->nLanguage[ 2 ] = nLang;
+                // #i119985#, we could probably handle this better if we have a
+                // place to over-ride the final language for weak
+                // characters/fields to fallback to, rather than the current
+                // application locale. Assuming that we can determine what the
+                // default fallback language for a given .ppt, etc is during
+                // load time.
+                if (i == 2)
+                {
+                    pEntry->nLanguage[ 0 ] = pEntry->nLanguage[ 1 ] = pEntry->nLanguage[ 2 ] = nLang;
+                }
             }
             nFlags &= ~i;
         }


More information about the Libreoffice-commits mailing list
diff --git a/sd/source/ui/dlg/headerfooterdlg.cxx b/sd/source/ui/dlg/headerfooterdlg.cxx
index e3efd36..3756d86 100644
--- a/sd/source/ui/dlg/headerfooterdlg.cxx
+++ b/sd/source/ui/dlg/headerfooterdlg.cxx
@@ -638,8 +638,8 @@ void HeaderFooterTabPage::GetOrSetDateTimeLanguage( LanguageType &rLanguage, boo
             }
         }
 
-        // and set it, or just get it from the handout master page
-        GetOrSetDateTimeLanguage( rLanguage, bSet, mpDoc->GetMasterSdPage( 0, PK_HANDOUT ) );
+        // #i119985# and set it, or just get it from the notes master page
+        GetOrSetDateTimeLanguage( rLanguage, bSet, mpDoc->GetMasterSdPage( 0, PK_NOTES ) );
     }
     else
     {
@@ -688,7 +688,7 @@ void HeaderFooterTabPage::GetOrSetDateTimeLanguage( LanguageType &rLanguage, boo
                     if( aFieldInfo.pFieldItem )
                     {
                         const SvxFieldData* pFieldData = aFieldInfo.pFieldItem->GetField();
-                        if( pFieldData && pFieldData->ISA( SvxDateTimeField ) )
+                        if( pFieldData && (pFieldData->ISA( SvxDateTimeField ) || pFieldData->ISA( SvxDateField )) )
                         {
                             break;
                         }
commit 8a5ad76b4e69b4ec742ed27d1825262681fb6f11
Author: Zhe Wang <wangzcdl at apache.org>
Date:   Mon Jun 25 05:23:47 2012 +0000

    Related: #i119985# date/time is displayed as different language
    
    (cherry picked from commit 2a3c87a5ea5e3308a138e461dffae19483c0184c)
    
    Change-Id: I3ef171481b206f7a9d356110d1b4a1559cd5e837
